
<p align="center">
    <a target="_blank" href='https://url.cn/Z4lzPLaF'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F1040x100-tencent.jpg" width="100%"/>
    </a>   
</p>



<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/potencent'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/potencent.svg?style=social" alt="github star"/>
    </a>
    	<a target="_blank" href='https://gitee.com/CoderWanFeng/potencent'>
		<img src='https://gitee.com/CoderWanFeng//potencent/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/Jf_EVdKlVnHhK68fW5OA6A">
	<img src="https://img.shields.io/badge/QQ-1090738447-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/wx-JkgOUoJhb-7ZESxl93w">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>
</p>


-------------------------------------------------------------------------------


## 📚简介


potencent 是快速调用腾讯云AI平台功能的接口合集。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://pypi.tuna.tsinghua.edu.cn/simple potencent -U
```


-------------------------------------------------------------------------------

## 📝功能

[📘官网：https://www.python-office.com/](https://www.python-office.com/)

## 通用文字识别相关接口

| 接口名称                                                     | 接口功能                   | 
| :----------------------------------------------------------- | :------------------------- | 
| [AdvertiseOCR](https://cloud.tencent.com/document/api/866/49524) | 广告文字识别               | 
| [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526) | 通用印刷体识别             | 
| [ImageEnhancement](https://cloud.tencent.com/document/api/866/80801) | 文本图像增强               | 
| [RecognizeHealthCodeOCR](https://cloud.tencent.com/document/api/866/68580) | 健康码识别                 | -        |
| [RecognizeTravelCardOCR](https://cloud.tencent.com/document/api/866/71657) | 通信行程卡识别             | -        |
| [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937) | 通用印刷体识别（高精度版） | -        |
| [GeneralEfficientOCR](https://cloud.tencent.com/document/api/866/37831) | 通用印刷体识别（精简版）   | -        |
| [GeneralFastOCR](https://cloud.tencent.com/document/api/866/33525) | 通用印刷体识别（高速版）   | -        |
| [EnglishOCR](https://cloud.tencent.com/document/api/866/34938) | 英文识别                   | -        |
| [GeneralHandwritingOCR](https://cloud.tencent.com/document/api/866/36212) | 通用手写体识别             | -        |
| [TextDetect](https://cloud.tencent.com/document/api/866/37830) | 快速文本检测               | 5        |

## 卡证文字识别相关接口

| 接口名称                                                     | 接口功能                         | 
| :----------------------------------------------------------- | :------------------------------- | 
| [BankCardOCR](https://cloud.tencent.com/document/api/866/36216) | 银行卡识别                       | -        |
| [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215) | 营业执照识别                     | -        |
| [BusinessCardOCR](https://cloud.tencent.com/document/api/866/36214) | 名片识别                         | 10       |
| [ClassifyDetectOCR](https://cloud.tencent.com/document/api/866/46770) | 智能卡证分类                     | 20       |
| [EnterpriseLicenseOCR](https://cloud.tencent.com/document/api/866/38849) | 企业证照识别                     | 5        |
| [EstateCertOCR](https://cloud.tencent.com/document/api/866/38300) | 不动产权证识别                   | 5        |
| [HKIDCardOCR](https://cloud.tencent.com/document/api/866/46919) | 中国香港身份证识别               | 5        |
| [HmtResidentPermitOCR](https://cloud.tencent.com/document/api/866/43106) | 港澳台居住证识别                 | 20       |
| [IDCardOCR](https://cloud.tencent.com/document/api/866/33524) | 身份证识别                       | -        |
| [InstitutionOCR](https://cloud.tencent.com/document/api/866/38299) | 事业单位法人证书识别             | 5        |
| [MLIDCardOCR](https://cloud.tencent.com/document/api/866/37656) | 马来西亚身份证识别               | 5        |
| [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657) | 护照识别（港澳台地区及境外护照） | -        |
| [MainlandPermitOCR](https://cloud.tencent.com/document/api/866/43105) | 港澳台来往内地通行证识别         | 20       |
| [OrgCodeCertOCR](https://cloud.tencent.com/document/api/866/38298) | 组织机构代码证识别               | 5        |
| [PassportOCR](https://cloud.tencent.com/document/api/866/37840) | 护照识别（中国大陆地区护照）     | 10       |
| [PermitOCR](https://cloud.tencent.com/document/api/866/37074) | 港澳台通行证识别                 | 10       |
| [PropOwnerCertOCR](https://cloud.tencent.com/document/api/866/40037) | 房产证识别                       | 5        |
| [RecognizeIndonesiaIDCardOCR](https://cloud.tencent.com/document/api/866/75195) | 印尼身份证识别                   | 20       |
| [RecognizePhilippinesDrivingLicenseOCR](https://cloud.tencent.com/document/api/866/75194) | 菲律宾驾驶证识别                 | 20       |
| [RecognizePhilippinesVoteIDOCR](https://cloud.tencent.com/document/api/866/75193) | 菲律宾VoteID识别                 | 20       |
| [RecognizeThaiIDCardOCR](https://cloud.tencent.com/document/api/866/48475) | 泰国身份证识别                   | 10       |
| [ResidenceBookletOCR](https://cloud.tencent.com/document/api/866/40036) | 户口本识别                       | 5        |

## 票据单据识别相关接口

| 接口名称                                                     | 接口功能               |
| :----------------------------------------------------------- | :--------------------- | 
| [BankSlipOCR](https://cloud.tencent.com/document/api/866/57674) | 银行回单识别           | 10       |
| [BusInvoiceOCR](https://cloud.tencent.com/document/api/866/37838) | 汽车票识别             | 5        |
| [CarInvoiceOCR](https://cloud.tencent.com/document/api/866/37076) | 购车发票识别           | 100      |
| [DutyPaidProofOCR](https://cloud.tencent.com/document/api/866/37839) | 完税证明识别           | 5        |
| [FinanBillOCR](https://cloud.tencent.com/document/api/866/38296) | 金融票据整单识别       | 5        |
| [FinanBillSliceOCR](https://cloud.tencent.com/document/api/866/38295) | 金融票据切片识别       | 5        |
| [FlightInvoiceOCR](https://cloud.tencent.com/document/api/866/37075) | 机票行程单识别         | 5        |
| [InvoiceGeneralOCR](https://cloud.tencent.com/document/api/866/37837) | 通用机打发票识别       | 5        |
| [MixedInvoiceDetect](https://cloud.tencent.com/document/api/866/37836) | 混贴票据分类           | 5        |
| [MixedInvoiceOCR](https://cloud.tencent.com/document/api/866/37835) | 混贴票据识别           | -        |
| [QuotaInvoiceOCR](https://cloud.tencent.com/document/api/866/37073) | 定额发票识别           | 5        |
| [RecognizeContainerOCR](https://cloud.tencent.com/document/api/866/63810) | 集装箱识别             | 5        |
| [RecognizeMedicalInvoiceOCR](https://cloud.tencent.com/document/api/866/80326) | 医疗票据识别           | 20       |
| [RecognizeOnlineTaxiItineraryOCR](https://cloud.tencent.com/document/api/866/62614) | 网约车行程单识别       | 20       |
| [ShipInvoiceOCR](https://cloud.tencent.com/document/api/866/37834) | 轮船票识别             | 5        |
| [TaxiInvoiceOCR](https://cloud.tencent.com/document/api/866/37072) | 出租车发票识别         | 5        |
| [TollInvoiceOCR](https://cloud.tencent.com/document/api/866/37833) | 过路过桥费发票识别     | 5        |
| [TrainTicketOCR](https://cloud.tencent.com/document/api/866/37071) | 火车票识别             | -        |
| [VatInvoiceOCR](https://cloud.tencent.com/document/api/866/36210) | 增值税发票识别         | -        |
| [VatRollInvoiceOCR](https://cloud.tencent.com/document/api/866/37832) | 增值税发票（卷票）识别 | 5        |
| [VerifyOfdVatInvoiceOCR](https://cloud.tencent.com/document/api/866/52296) | OFD发票识别            | 10       |
| [WaybillOCR](https://cloud.tencent.com/document/api/866/34934) | 运单识别               | -        |

## 汽车场景识别相关接口

| 接口名称                                                     | 接口功能           | 
| :----------------------------------------------------------- | :----------------- | 
| [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213) | 驾驶证识别         | -        |
| [LicensePlateOCR](https://cloud.tencent.com/document/api/866/36211) | 车牌识别           | -        |
| [RideHailingDriverLicenseOCR](https://cloud.tencent.com/document/api/866/47165) | 网约车驾驶证识别   | 5        |
| [RideHailingTransportLicenseOCR](https://cloud.tencent.com/document/api/866/47325) | 网约车运输证识别   | 5        |
| [VehicleLicenseOCR](https://cloud.tencent.com/document/api/866/36209) | 行驶证识别         | -        |
| [VehicleRegCertOCR](https://cloud.tencent.com/document/api/866/38297) | 机动车登记证书识别 | 5        |
| [VinOCR](https://cloud.tencent.com/document/api/866/34935)   | 车辆VIN码识别      | 10       |

## 行业文档识别相关接口

| 接口名称                                                     | 接口功能       | 
| :----------------------------------------------------------- | :------------- | 
| [RecognizeTableOCR](https://cloud.tencent.com/document/api/866/49525) | 表格识别（V2)  | 10       |
| [ArithmeticOCR](https://cloud.tencent.com/document/api/866/34939) | 算式识别       | 10       |
| [EduPaperOCR](https://cloud.tencent.com/document/api/866/38294) | 数学试题识别   | 5        |
| [FormulaOCR](https://cloud.tencent.com/document/api/866/38293) | 数学公式识别   | 5        |
| [InsuranceBillOCR](https://cloud.tencent.com/document/api/866/38848) | 保险单据识别   | 1        |
| [SealOCR](https://cloud.tencent.com/document/api/866/45807)  | 印章识别       | 5        |
| [SmartStructuralOCR](https://cloud.tencent.com/document/api/866/60877) | 智能结构化识别 | -        |
| [TableOCR](https://cloud.tencent.com/document/api/866/34936) | 表格识别（V1)  | 10       |

## 智能扫码相关接口

| 接口名称                                                     | 接口功能           | 
| :----------------------------------------------------------- | :----------------- | 
| [QueryBarCode](https://cloud.tencent.com/document/api/866/45513) | 条码信息查询       | 5        |
| [QrcodeOCR](https://cloud.tencent.com/document/api/866/38292) | 二维码和条形码识别 | 5        |

## 营业执照核验相关接口

| 接口名称                                                     | 接口功能                     | 
| :----------------------------------------------------------- | :--------------------------- | 
| [VerifyBasicBizLicense](https://cloud.tencent.com/document/api/866/47279) | 营业执照识别及核验（基础版） | 20       |
| [VerifyBizLicense](https://cloud.tencent.com/document/api/866/47278) | 营业执照识别及核验（详细版） | 5        |
| [VerifyEnterpriseFourFactors](https://cloud.tencent.com/document/api/866/55857) | 企业四要素核验               | 20       |

## 增值税发票核验相关接口

| 接口名称                                                     | 接口功能               | 
| :----------------------------------------------------------- | :--------------------- |
| [VatInvoiceVerify](https://cloud.tencent.com/document/api/866/47324) | 增值税发票核验         | 20       |
| [VatInvoiceVerifyNew](https://cloud.tencent.com/document/api/866/73674) | 增值税发票核验（新版） | 20       |




## 🏗️添砖加瓦


### 📐PR的建议

python-office欢迎任何人来添砖加瓦，贡献代码，建议提交的pr（pull request）符合一些规范，规范如下：

参与项目建设的步骤：
- 例如：你需要给python-office添加一个add方法。
   1. 你的Github账户名为：demo
   2. 于是你在./contributors新建了文件夹./demo
   3. 新建了add.py文件，编辑你的代码
   4. 编辑完成，提交pr到master分支（gitee或者GitHub，都可以）。可以注明你对自己功能的取名建议
   5. 晚枫收到后，会对各位的代码进行测试后，合并后打包上传到python官方库

### 📐代码规范

1. 注释完备，尤其每个新增的方法应按照Google Python文档规范标明方法说明、参数说明、返回值说明等信息，必要时请添加单元测试，如果愿意，也可以加上你的大名。
2. python-office的文档，需要进行格式化。注意：只能格式化你自己的代码
3. 请直接pull request到`master`分支。`master`是主分支，表示已经发布pypi库的版本。**未来参与人数增多，会开辟新的分支，请留意本文档的更新。**
4. 我们如果关闭了你的issue或pr，请不要诧异，这是我们保持问题处理整洁的一种方式，你依旧可以继续讨论，当有讨论结果时我们会重新打开。


### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待维护者合并


### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/pobaidu/issues)

-------------------------------------------------------------------------------


## 📌联系作者


![CoderWanFeng](https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg)